uifw/AvKon/src/AknSctDialog.cpp
branchRCL_3
changeset 51 fcdfafb36fe7
parent 18 0aa5fbdfbc30
child 55 aecbbf00d063
--- a/uifw/AvKon/src/AknSctDialog.cpp	Thu Jul 15 18:56:19 2010 +0300
+++ b/uifw/AvKon/src/AknSctDialog.cpp	Thu Aug 19 10:11:06 2010 +0300
@@ -434,10 +434,12 @@
     // to select multiple characters before.
     if (aButtonId == EAknSoftkeyOk || aButtonId == EAknSoftkeySelect || aButtonId == EAknSoftkeyExit)
         {
         // In Japanese UI, SCT isn't closed by pressing "Select" softkey,
         // but SCT is closed by pressing "Back"(button id is EAknSoftkeyClose).
+        // Japanese feature for SCT will not be supported since TB9.2 PS2,
+        // so remove the code for Japanese SCT.
         MAknSctFocusHandler* handler = charmapControl->FocusHandler();
-        if (charmapControl->IsJapaneseSctUi() &&
+        if ( charmapControl->IsKoreanSctUi() &&
             aButtonId != EAknSoftkeyExit &&
             handler->FocusedControl() == charmapControl)
             {
@@ -434,10 +434,12 @@
     if (aButtonId == EAknSoftkeyOk || aButtonId == EAknSoftkeySelect || aButtonId == EAknSoftkeyExit)
         {
-        // In Japanese UI, SCT isn't closed by pressing "Select" softkey,
+        // In Korean UI, SCT isn't closed by pressing "Select" softkey,
         // but SCT is closed by pressing "Back"(button id is EAknSoftkeyClose).